;; Generated package description from inspector.el  -*- no-byte-compile: t -*-
(define-package "inspector" "0.35" "Tool for inspection of Emacs Lisp objects" '((emacs "27.1")) :commit "86f26bf7a78e791879e95d4d430aab1e3a6e8efe" :authors '(("Mariano Montone" . "marianomontone@gmail.com")) :maintainer '("Mariano Montone" . "marianomontone@gmail.com") :keywords '("debugging" "tool" "lisp" "development") :url "https://github.com/mmontone/emacs-inspector")
